class CardResponseModel {
  final String? id;
  final String? state;
  final String? createdAt;
  final String? message;
  final CardDetails? details;

  CardResponseModel({
    required this.id,
    required this.state,
    required this.createdAt,
    required this.details,
    this.message,
  });

  factory CardResponseModel.fromJson(Map json) {
    return CardResponseModel(
      id: json['cardId'],
      state: json['state'],
      createdAt: json['createdAt'],
      message: json['message'],
      details: json['details'] != null
          ? CardDetails.fromJson(json['details'])
          : null,
    );
  }
}

class CardDetails {
  final CardDetail? groupNumber;
  final CardDetail? memberNumber;
  final CardDetail? payerName;
  final CardDetail? rxBin;
  final CardDetail? rxPcn;
  final CardDetail? rxGroup;
  final CardDetail? memberName;
  final List<CardDetail>? dependentNames;
  final CardDetail? planName;
  final CardDetail? planId;
  final CardDetail? cardSpecificId;
  final CardDetail? startDate;

  CardDetails({
    this.groupNumber,
    this.memberNumber,
    this.payerName,
    this.rxBin,
    this.rxPcn,
    this.rxGroup,
    this.memberName,
    this.dependentNames,
    this.planName,
    this.planId,
    this.cardSpecificId,
    this.startDate,
  });

  factory CardDetails.fromJson(Map json) {
    return CardDetails(
      groupNumber: CardDetail.fromJson(json['groupNumber']),
      memberNumber: CardDetail.fromJson(json['memberNumber']),
      payerName: CardDetail.fromJson(json['payerName']),
      rxBin: CardDetail.fromJson(json['rxBin']),
      rxPcn: CardDetail.fromJson(json['rxPCN']),
      rxGroup: CardDetail.fromJson(json['rxGroup']),
      memberName: CardDetail.fromJson(json['memberName']),
      dependentNames: json['dependentNames'] is List
          ? (json['dependentNames'] as List)
              .map((e) => CardDetail.fromJson(e))
              .whereType<CardDetail>()
              .toList()
          : [],
      planName: CardDetail.fromJson(json['planName']),
      planId: CardDetail.fromJson(json['planId']),
      cardSpecificId: CardDetail.fromJson(json['cardSpecificId']),
      startDate: CardDetail.fromJson(json['startDate']),
    );
  }
}

class CardDetail {
  final dynamic value;
  final List<double> scores;

  CardDetail(this.value, this.scores);

  static CardDetail? fromJson(dynamic json) {
    if (json is Map) {
      try {
        return CardDetail(
            json['value'], (json['scores'] as List).cast<double>());
      } catch (e) {
        return null;
      }
    }
    return null;
  }
}
