import 'package:flutter/foundation.dart';

class ScannedCard {
  final String id;
  final String name;
  final String memberId;
  final String groupId;
  final DateTime? date;
  final List<String> dependents;
  final String planName;
  final String planId;
  final String payerName;
  final String rxBin;
  final String rxPcn;
  final String rxGroup;
  final String cardSpecificId;
  final String startDate;
  final CardState state;
  final String? message;
  String? imageUrl;

  ScannedCard(
      {required this.id,
      required this.name,
      required this.memberId,
      required this.groupId,
      required this.date,
      required this.dependents,
      required this.planId,
      required this.planName,
      required this.payerName,
      required this.rxBin,
      required this.rxPcn,
      required this.rxGroup,
      required this.startDate,
      required this.state,
      required this.cardSpecificId,
      this.message});

  @override
  String toString() {
    return 'ScannedCard{id: $id, name: $name, memberId: $memberId, groupId: $groupId, '
        'date: $date, dependents: $dependents, planName: $planName, planId: $planId, '
        'payerName: $payerName, rxBin: $rxBin, rxPcn: $rxPcn, rxGroup: $rxGroup, '
        'cardSpecificId: $cardSpecificId, startDate: $startDate, state: $state, '
        'message: $message}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is ScannedCard &&
          runtimeType == other.runtimeType &&
          id == other.id &&
          name == other.name &&
          memberId == other.memberId &&
          groupId == other.groupId &&
          date == other.date &&
          listEquals(dependents, other.dependents) &&
          planName == other.planName &&
          planId == other.planId &&
          payerName == other.payerName &&
          rxBin == other.rxBin &&
          rxPcn == other.rxPcn &&
          rxGroup == other.rxGroup &&
          cardSpecificId == other.cardSpecificId &&
          startDate == other.startDate &&
          state == other.state &&
          message == other.message;

  @override
  int get hashCode =>
      id.hashCode ^
      name.hashCode ^
      memberId.hashCode ^
      groupId.hashCode ^
      date.hashCode ^
      dependents.hashCode ^
      planName.hashCode ^
      planId.hashCode ^
      payerName.hashCode ^
      rxBin.hashCode ^
      rxPcn.hashCode ^
      rxGroup.hashCode ^
      cardSpecificId.hashCode ^
      startDate.hashCode ^
      state.hashCode ^
      message.hashCode;
}

enum CardState { completed, processing, error }

extension CardStateExt on CardState {
  String get name {
    switch (this) {
      case CardState.completed:
        return 'Completed';
      case CardState.processing:
        return 'Processing';
      case CardState.error:
        return 'Error';
    }
  }
}
